.. _users-guide-index:

============
 User Guide
============
	
:Release: |version|
:Date: |today|

.. toctree::
   :maxdepth: 2

   install
   config_file
   interface_tutorial
   pipeline_tutorial
   parallel_processing


 



